@@ -1,55 +1,67 @@
 /*
- * Copyright (C) 2006, 2007, 2008, 2009 Free Software Foundation
- * Copyright (C) 2002 Fabio Fiorina
+ *      Copyright (C) 2002 Fabio Fiorina
  *
- * This file is part of LIBTASN1.
+ * This file is part of LIBASN1.
  *
- * This program is free software: you can redistribute it and/or modify
+ * LIBASN1 is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * LIBASN1 is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
 
 /*****************************************************/
 /* File: asn1Deoding.c                               */
 /* Description: program to generate an ASN1 type from*/
-/*              a DER coding.                        */
+/*              a DER coding.                        */   
 /*****************************************************/
 
-#include <config.h>
-
 #include <stdio.h>
 #include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <getopt.h>
-
 #include <libtasn1.h>
+#include <stdlib.h>
+#include <config.h>
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#ifdef HAVE_GETOPT_H
+  #include <getopt.h>
+#endif
+
+char version_man[] = "asn1Decoding (GNU libtasn1) " VERSION;
+
+char help_man[] = "asn1Decoding generates an ASN1 type from a file\n"
+                  "with ASN1 definitions and another one with a DER encoding.\n"
+                  "\n"
+                  "Usage: asn1Decoding [options] <file1> <file2> <type>\n"
+                  " <file1> file with ASN1 definitions.\n"
+                  " <file2> file with a DER coding.\n"
+                  " <type>  ASN1 type name\n"
+                  "\n"
+#ifdef HAVE_GETOPT_LONG
+                  "Operation modes:\n"
+                  "  -h, --help    shows this message and exit.\n"
+                  "  -v, --version shows version information and exit.\n"
+                  "  -c, --check   checks the syntax only.\n";
+#else
+                  "Operation modes:\n"
+                  "  -h    shows this message and exit.\n"
+                  "  -v    shows version information and exit.\n"
+                  "  -c    checks the syntax only.\n";
+#endif
 
-#include <progname.h>
-#include <version-etc.h>
-#include <read-file.h>
 
-static const char help_man[] =
-  "Usage: asn1Decoding [OPTION] DEFINITIONS ENCODED ASN1TYPE\n"
-  "asn1Decoding decodes DER data in ENCODED file, for the ASN1TYPE element\n"
-  "described in ASN.1 DEFINITIONS file, and print decoded structures.\n"
-  "\n"
-  "  -c, --check           checks the syntax only\n"
-  "  -h, --help            display this help and exit\n"
-  "  -v, --version         output version information and exit.\n"
-  "\n"
-  "Report bugs to <" PACKAGE_BUGREPORT ">.";
 
 /********************************************************/
 /* Function : main                                      */
@@ -58,6 +70,8 @@ static const char help_man[] =
 int
 main(int argc,char *argv[])
 {
+
+#ifdef HAVE_GETOPT_LONG
   static struct option long_options[] =
   {
     {"help",    no_argument,       0, 'h'},
@@ -66,6 +80,8 @@ main(int argc,char *argv[])
     {0, 0, 0, 0}
   };
  int option_index = 0;
+#endif
+
  int option_result;
  char *inputFileAsnName=NULL;
  char *inputFileDerName=NULL; 
@@ -73,19 +89,24 @@ main(int argc,char *argv[])
  int checkSyntaxOnly=0;
  ASN1_TYPE definitions=ASN1_TYPE_EMPTY;
  ASN1_TYPE structure=ASN1_TYPE_EMPTY;
- char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
+ char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
  int asn1_result=ASN1_SUCCESS;
- unsigned char *der;
+ FILE *inputFile;
+ unsigned char der[100*1024];
  int  der_len=0;
  /* FILE *outputFile; */ 
 
- set_program_name (argv[0]);
-
  opterr=0; /* disable error messages from getopt */
 
+ printf("\n");
+
  while(1){
 
+#ifdef HAVE_GETOPT_LONG
    option_result=getopt_long(argc,argv,"hvc",long_options,&option_index);
+#else
+   option_result=getopt(argc,argv,"hvc");
+#endif
 
    if(option_result == -1) break;
 
@@ -95,8 +116,7 @@ main(int argc,char *argv[])
      exit(0);
      break;
    case 'v':  /* VERSION */
-     version_etc (stdout, program_name, PACKAGE, VERSION,
-		  "Fabio Fiorina", NULL);
+     printf("%s\n",version_man);
      exit(0);
      break;
    case 'c':  /* CHECK SYNTAX */
@@ -161,7 +181,7 @@ main(int argc,char *argv[])
    printf("asn1Decoding: %s\n",errorDescription);
    break;
  default:
-   printf("libtasn1 ERROR: %s\n",asn1_strerror(asn1_result));
+   printf("libtasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
  }
 
  if(asn1_result != ASN1_SUCCESS){
@@ -172,14 +192,10 @@ main(int argc,char *argv[])
  }
 
 
- {
-   size_t tmplen;
-   der = (unsigned char*) read_binary_file (inputFileDerName, &tmplen);
-   der_len = tmplen;
- }
+ inputFile=fopen(inputFileDerName,"r");
 
- if(der==NULL){
-   printf("asn1Decoding: could not read '%s'\n",inputFileDerName);
+ if(inputFile==NULL){
+   printf("asn1Decoding: file '%s' not found\n",inputFileDerName);
    asn1_delete_structure(&definitions);
 
    free(inputFileAsnName);
@@ -204,24 +220,29 @@ main(int argc,char *argv[])
  fclose(inputFile);
  */
  
+ while(fscanf(inputFile,"%c",der+der_len) != EOF){
+   der_len++;
+ }
+ fclose(inputFile);
+
+    
  asn1_result=asn1_create_element(definitions,typeName,&structure);
 
  /* asn1_print_structure(stdout,structure,"",ASN1_PRINT_ALL); */
 
 
  if(asn1_result != ASN1_SUCCESS){
-   printf("Structure creation: %s\n",asn1_strerror(asn1_result));
+   printf("Structure creation: %s\n",libtasn1_strerror(asn1_result));
    asn1_delete_structure(&definitions);
 
    free(inputFileAsnName);
    free(inputFileDerName);
    free(typeName);   
-   free(der);
    exit(1);
  }
 
  asn1_result=asn1_der_decoding(&structure,der,der_len,errorDescription);
- printf("\nDecoding: %s\n",asn1_strerror(asn1_result));
+ printf("\nDecoding: %s\n",libtasn1_strerror(asn1_result));
  if(asn1_result != ASN1_SUCCESS)
    printf("asn1Decoding: %s\n",errorDescription);
 
@@ -247,8 +268,6 @@ main(int argc,char *argv[])
  asn1_delete_structure(&definitions);
  asn1_delete_structure(&structure);
 
- free(der);
-
  free(inputFileAsnName);
  free(inputFileDerName);
  free(typeName);  
@@ -258,3 +277,10 @@ main(int argc,char *argv[])
 
  exit(0);
 }
+
+
+
+
+
+
+
